"""HTML report format plugin."""

# Copyright (c) 2022-2025, Broadband Forum
#
# Redistribution and use in source and binary forms, with or
# without modification, are permitted provided that the following
# conditions are met:
#
# 1. Redistributions of source code must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
#
# 2. Redistributions in binary form must reproduce the above
#    copyright notice, this list of conditions and the following
#    disclaimer in the documentation and/or other materials
#    provided with the distribution.
#
# 3. Neither the name of the copyright holder nor the names of its
#    contributors may be used to endorse or promote products
#    derived from this software without specific prior written
#    permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND
# CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
# INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
# MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
# DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR
# CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
# SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
# NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
# LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
# CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
# STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
# ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
# ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#
# The above license is used as a license under copyright only.
# Please reference the Forum IPR Policy for patent licensing terms
# <https://www.broadband-forum.org/ipr-policy>.
#
# Any moral rights which are necessary to exercise under the above
# license grant are also deemed granted under this license.

# pyright: reportUnusedFunction=false

import argparse
import logging

from typing import Any

from ..macro import Macro
from ..node import Root
from ..visitor import Rules

from .shared.markdown import ModelTableElem, Report


# return type is argparse._ArgumentGroup (it's private and not exported)
def _add_arguments_(arg_parser: argparse.ArgumentParser) -> Any:
    arg_group = arg_parser.add_argument_group('html report format arguments')
    arg_group.add_argument('--html-use-commonmark', action='store_true',
                           help='use the built-in (and currently much '
                                'slower) Commonmark parser')
    return arg_group


def _post_init_() -> None:
    # redefine the 'classes' macro (if it was originally declared as non-final,
    # this won't output a warning)
    Macro('classes', default='', macro_body=ModelTableElem.expand_classes)


# visit the node tree
def visit(root: Root, args: argparse.Namespace, *, omit_if_unused: bool,
          rules: Rules, logger: logging.Logger) -> None:
    Report(root, args, omit_if_unused=omit_if_unused, rules=rules,
           logger=logger)
